# Document Search

Supported Documents

* YouTube (will read transcripts)
* Arxiv papers
* PDFs
* Git repos
* any HTML
* Local file system


## How to use

1. Structure a query like this:

```yaml
query:
docs:
  - title: optional
    url: ...
  - title: ...
    url: ...
```


2. Trigger the code action and related passages will be inserted into your document!
